@@ -149,7 +149,7 @@ sub journalist {
         $ret = $guess->attr('content');
     } elsif ( $guess = $dom->at('meta[name="author"]') ) {
         $ret = $guess->attr('content');
-    } elsif ( $guess = $dom->at('div.field-item a[href^=/author/], div.content_reporter a[itemprop=author], span[itemprop=author] a, div.author div.intro a div.name, div.article-author > h5 > a, div.article-meta > div.article-author > a, div.authorInfo li.authorName > a, .article .writer > p, .info_author, .news-info dd[itemprop=author], .content_reporter a, .top_title span.reporter_name, .post-heading time span, header .article-meta .article-author,  .article_header > .author > span:first-child, .mid-news > .m-left-side > .maintype-wapper > .subtype-sort, .newsCon > .newsInfo > span:first-child, .newsdetail_content > .title > h4 > a[href^="/news/searchresult/news?search_text="]') ) {
+    } elsif ( $guess = $dom->at('div.field-item a[href^=/author/], div.content_reporter a[itemprop=author], span[itemprop=author] a, div.author div.intro a div.name, div.article-author > h5 > a, div.article-meta > div.article-author > a, div.authorInfo li.authorName > a, .article .writer > p, .info_author, .news-info dd[itemprop=author], .content_reporter a, .top_title span.reporter_name, .post-heading time span, header .article-meta .article-author,  .article_header > .author > span:first-child, .mid-news > .m-left-side > .maintype-wapper > .subtype-sort, .newsCon > .newsInfo > span:first-child, .newsdetail_content > .title > h4 > a[href^="/news/searchresult/news?search_text="], .m-from-author > .m-from-author__name') ) {
         $ret = $guess->text;
     } elsif ($guess = $dom->at('.story_bady_info_author')) {
         if ($guess->find('a')->size() == 0) {
@@ -169,6 +169,8 @@ sub journalist {
         $ret = $guess->text;
     } elsif ($guess = $dom->at('.fncnews-content > .info > span.small-gray-text')) {
         ($ret) = $guess->text =~ m<(責任編輯.+)\z>x;
+    } elsif ($guess = $dom->at('div.single-post-meta a[rel="author"]')) {
+        ($ret) = $guess->text =~ m<^工商時報 (.+)\z>x;
     }
 
     $ret = undef if ($ret && is_NewspaperName($ret));
